@@ -10,13 +10,13 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main.cpp" line="47"/>
-        <source>Deepin Picker is a fast screen color picking tool. RGB and HEX code can be obtained according color picked and auto saved to clipboard. The color picking area is where mouse clicked.</source>
-        <translation>Deepin Picker è un tool per rilevare i colori. I codici RGB e HEX del colore selezionato vengono rilevati e salvati negli appunti. I codici colori riguardano ovviamente l&apos;area in cui si seleziona col puntatore del Mouse.
+        <location filename="../src/main.cpp" line="50"/>
+        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
+        <translation>Deepin Picker è un tool per rilevare i colori. I codici RGB e HEX del colore selezionato vengono rilevati e salvati negli appunti.
 Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="69"/>
+        <location filename="../src/main.cpp" line="72"/>
         <source>Deepin Picker</source>
         <translation>Deepin Picker</translation>
     </message>
