@@ -4,18 +4,18 @@
     <message>
         <location filename="../src/clipboard.cpp" line="79"/>
         <source>Copy color %1 to clipboard</source>
-        <translation>顏色 %1 已複製到剪貼簿</translation>
+        <translation>將顏色 %1 複製到剪貼簿</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/main.cpp" line="47"/>
-        <source>Deepin Picker is a fast screen color picking tool. RGB and HEX code can be obtained according color picked and auto saved to clipboard. The color picking area is where mouse clicked.</source>
-        <translation>Deepin 取色器是款快速的螢幕取色工具。透過滑鼠選擇顏色後，能自動將 RGB 及十六進位等色彩模式儲存到剪貼簿。</translation>
+        <location filename="../src/main.cpp" line="50"/>
+        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
+        <translation>Deepin 取色器是款快速且簡單的螢幕取色工具。可透過點選取得 RGB 及十六進位色彩碼，並自動複製到剪貼簿。</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="69"/>
+        <location filename="../src/main.cpp" line="72"/>
         <source>Deepin Picker</source>
         <translation>Deepin 取色器</translation>
     </message>
